@@ -1,7 +1,4 @@
 package Data::Dump::PHP::Trace;
-BEGIN {
-  $Data::Dump::PHP::Trace::VERSION = '0.07';
-}
 
 # Todo:
 #   - prototypes
@@ -108,9 +105,6 @@ sub mcall {
 }
 
 package Data::Dump::PHP::Trace::Wrapper;
-BEGIN {
-  $Data::Dump::PHP::Trace::Wrapper::VERSION = '0.07';
-}
 
 sub AUTOLOAD {
     my $self = shift;
@@ -120,9 +114,6 @@ sub AUTOLOAD {
 }
 
 package Data::Dump::PHP::Trace::Call;
-BEGIN {
-  $Data::Dump::PHP::Trace::Call::VERSION = '0.07';
-}
 
 use Term::ANSIColor ();
 use Data::Dump::PHP ();
@@ -280,9 +271,15 @@ sub errno {
 
 __END__
 
+=pod
+
 =head1 NAME
 
-Data::Dump::PHP::Trace - Helpers to trace function and method calls
+Data::Dump::PHP::Trace
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -404,6 +401,10 @@ prefix), and the function returns a blessed object, then the variable
 name will be used as prefix and the returned object automatically
 traced.
 
+=head1 NAME
+
+Data::Dump::PHP::Trace - Helpers to trace function and method calls
+
 =head1 SEE ALSO
 
 L<Data::Dump::PHP>
@@ -417,4 +418,15 @@ Copyright 2010 Steven Haryanto.
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
